@@ -15,7 +15,7 @@ class Earlybyte:
         default_factory=lambda: [
             "Passion",
             "Simplicity",
-            "Fellowship",
+            "Community",
             "Authenticity",
             "Curiosity",
         ]
